==> psdb-1.0.5-py3-none-any.whl: psdb/devices/stm32/adc.py <==
# Copyright (c) 2019 Phase Advanced Sensor Systems, Inc.
from builtins import range

from ..device import Device, Reg32, Reg32R


class ADC(Device):
    '''
    Driver for the STM32G4 ADC.
    '''
    PER_ADC_REGS = [(Reg32,  'ISR',     0x00, [('ADRDY',        1),
                                               ('EOSMP',        1),
                                               ('EOC',          1),
                                               ('EOS',          1),
                                               ('OVR',          1),
                                               ('JEOC',         1),
                                               ('JEOS',         1),
                                               ('AWD1',         1),
                                               ('AWD2',         1),
                                               ('AWD3',         1),
                                               ('JQOVF',        1),
                                               ]),
                    (Reg32,  'IER',     0x04, [('ADRDYIE',      1),
                                               ('EOSMPIE',      1),
                                               ('EOCIE',        1),
                                               ('EOSIE',        1),
                                               ('OVRIE',        1),
                                               ('JEOCIE',       1),
                                               ('JEOSIE',       1),
                                               ('AWD1IE',       1),
                                               ('AWD2IE',       1),
                                               ('AWD3IE',       1),
                                               ('JQOVFIE',      1),
                                               ]),
                    (Reg32,  'CR',      0x08, [('ADEN',         1),
                                               ('ADDIS',        1),
                                               ('ADSTART',      1),
                                               ('JADSTART',     1),
                                               ('ADSTP',        1),
                                               ('JADSTP',       1),
                                               ('',             22),
                                               ('ADVREGEN',     1),
                                               ('DEEPPWD',      1),
                                               ('ADCALDIF',     1),
                                               ('ADCAL',        1),
                                               ]),
                    (Reg32,  'CFGR',    0x0C, [('DMAEN',        1),
                                               ('DMACFG',       1),
                                               ('',             1),
                                               ('RES',          2),
                                               ('EXTSEL0',      1),
                                               ('EXTSEL1',      1),
                                               ('EXTSEL2',      1),
                                               ('EXTSEL3',      1),
                                               ('EXTSEL4',      1),
                                               ('EXTEN',        2),
                                               ('OVRMOD',       1),
                                               ('CONT',         1),
                                               ('AUTDLY',       1),
                                               ('ALIGN',        1),
                                               ('DISCEN',       1),
                                               ('DISCNUM',      3),
                                               ('JDISCEN',      1),
                                               ('JQM',          1),
                                               ('AWD1SGL',      1),
                                               ('AWD1EN',       1),
                                               ('JAWD1EN',      1),
                                               ('JAUTO',        1),
                                               ('AWD1CH',       5),
                                               ('JQDIS',        1),
                                               ]),
                    (Reg32,  'CFGR2',   0x10, [('ROVSE',        1),
                                               ('JOVSE',        1),
                                               ('OVSR',         3),
                                               ('OCSS',         4),
                                               ('TROVS',        1),
                                               ('ROVSM',        1),
                                               ('',             5),
                                               ('GCOMP',        1),
                                               ('',             8),
                                               ('SWTRIG',       1),
                                               ('BULB',         1),
                                               ('SMPTRIG',      1),
                                               ]),
                    (Reg32,  'SMPR1',   0x14, [('SMP0',         3),
                                               ('SMP1',         3),
                                               ('SMP2',         3),
                                               ('SMP3',         3),
                                               ('SMP4',         3),
                                               ('SMP5',         3),
                                               ('SMP6',         3),
                                               ('SMP7',         3),
                                               ('SMP8',         3),
                                               ('SMP9',         3),
                                               ('',             1),
                                               ('SMPPLUS',      1),
                                               ]),
                    (Reg32,  'SMPR2',   0x18, [('SMP10',        3),
                                               ('SMP11',        3),
                                               ('SMP12',        3),
                                               ('SMP13',        3),
                                               ('SMP14',        3),
                                               ('SMP15',        3),
                                               ('SMP16',        3),
                                               ('SMP17',        3),
                                               ('SMP18',        3),
                                               ]),
                    (Reg32,  'TR1',     0x20, [('LT1',          12),
                                               ('AWDFILT',      3),
                                               ('',             1),
                                               ('HT1',          12),
                                               ]),
                    (Reg32,  'TR2',     0x24, [('LT2',          8),
                                               ('',             8),
                                               ('HT2',          8),
                                               ]),
                    (Reg32,  'TR3',     0x28, [('LT3',          8),
                                               ('',             8),
                                               ('HT3',          8),
                                               ]),
                    (Reg32,  'SQR1',    0x30, [('L',            4),
                                               ('',             2),
                                               ('SQ1',          5),
                                               ('',             1),
                                               ('SQ2',          5),
                                               ('',             1),
                                               ('SQ3',          5),
                                               ('',             1),
                                               ('SQ4',          5),
                                               ]),
                    (Reg32,  'SQR2',    0x34, [('SQ5',          5),
                                               ('',             1),
                                               ('SQ6',          5),
                                               ('',             1),
                                               ('SQ7',          5),
                                               ('',             1),
                                               ('SQ8',          5),
                                               ('',             1),
                                               ('SQ9',          5),
                                               ]),
                    (Reg32,  'SQR3',    0x38, [('SQ10',         5),
                                               ('',             1),
                                               ('SQ11',         5),
                                               ('',             1),
                                               ('SQ12',         5),
                                               ('',             1),
                                               ('SQ13',         5),
                                               ('',             1),
                                               ('SQ14',         5),
                                               ]),
                    (Reg32,  'SQR4',    0x3C, [('SQ15',         5),
                                               ('',             1),
                                               ('SQ16',         5),
                                               ]),
                    (Reg32R, 'DR',      0x40, [('RDATA',        16)]),
                    (Reg32,  'JSQR',    0x4C, [('JL',           2),
                                               ('JEXTSEL',      5),
                                               ('JEXTEN',       2),
                                               ('JSQ1',         5),
                                               ('',             1),
                                               ('JSQ2',         5),
                                               ('',             1),
                                               ('JSQ3',         5),
                                               ('',             1),
                                               ('JSQ4',         5),
                                               ]),
                    (Reg32,  'OFR1',    0x60, [('OFFSET1',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET1_CH',   5),
                                               ('OFFSET1_EN',   1),
                                               ]),
                    (Reg32,  'OFR2',    0x64, [('OFFSET2',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET2_CH',   5),
                                               ('OFFSET2_EN',   1),
                                               ]),
                    (Reg32,  'OFR3',    0x68, [('OFFSET3',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET3_CH',   5),
                                               ('OFFSET3_EN',   1),
                                               ]),
                    (Reg32,  'OFR4',    0x6C, [('OFFSET4',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET4_CH',   5),
                                               ('OFFSET4_EN',   1),
                                               ]),
                    (Reg32R, 'JDR1',    0x80, [('JDATA',        16)]),
                    (Reg32R, 'JDR2',    0x84, [('JDATA',        16)]),
                    (Reg32R, 'JDR3',    0x88, [('JDATA',        16)]),
                    (Reg32R, 'JDR4',    0x8C, [('JDATA',        16)]),
                    (Reg32,  'AWD2CR',  0xA0, [('AWD2CH',       19)]),
                    (Reg32,  'AWD3CR',  0xA4, [('AWD3CH',       19)]),
                    (Reg32,  'DIFSEL',  0xB0, [('DIFSEL',       19)]),
                    (Reg32,  'CALFACT', 0xB4, [('CALFACT_S',    7),
                                               ('',             9),
                                               ('CALFACT_D',    7),
                                               ]),
                    (Reg32,  'GCOMP',   0xC0, [('GCOMPCOEFF',   14)]),
                    ]
    COM_ADC_REGS = [Reg32R('CSR', 0x300,      [('ADRDY_MST',    1),
                                               ('EOSMP_MST',    1),
                                               ('EOC_MST',      1),
                                               ('EOS_MST',      1),
                                               ('OVR_MST',      1),
                                               ('JEOC_MST',     1),
                                               ('JEOS_MST',     1),
                                               ('AWD1_MST',     1),
                                               ('AWD2_MST',     1),
                                               ('AWD3_MST',     1),
                                               ('JQOVF_MST',    1),
                                               ('',             5),
                                               ('ADRDY_SLV',    1),
                                               ('EOSMP_SLV',    1),
                                               ('EOC_SLV',      1),
                                               ('EOS_SLV',      1),
                                               ('OVR_SLV',      1),
                                               ('JEOC_SLV',     1),
                                               ('JEOS_SLV',     1),
                                               ('AWD1_SLV',     1),
                                               ('AWD2_SLV',     1),
                                               ('AWD3_SLV',     1),
                                               ('JQOVF_SLV',    1),
                                               ]),
                    Reg32 ('CCR', 0x308,      [('DUAL',         5),
                                               ('',             3),
                                               ('DELAY',        4),
                                               ('',             1),
                                               ('DMACFG',       1),
                                               ('MDMA',         2),
                                               ('CKMODE',       2),
                                               ('PRESC',        4),
                                               ('VREFEN',       1),
                                               ('VSENSESEL',    1),
                                               ('VBATSEL',      1),
                                               ]),
                    Reg32R('CDR', 0x30C,      [('RDATA_MST',    16),
                                               ('RDATA_SLV',    16),
                                               ]),
                    ]

    def __init__(self, target, ap, name, addr, first_adc, nadcs, **kwargs):
        regs = []
        for i in range(nadcs):
            base = 0x100*i
            regs += [cls(_name + ('_%u' % (first_adc + i)), base + offset,
                         fields)
                     for cls, _name, offset, fields in ADC.PER_ADC_REGS]
        regs += ADC.COM_ADC_REGS

        super(ADC, self).__init__(target, ap, addr, name, regs, **kwargs)

==> psdb-1.1.6-py3-none-any.whl: psdb/devices/stm32/adc.py <==
# Copyright (c) 2019 Phase Advanced Sensor Systems, Inc.
from builtins import range

from ..device import Device, Reg32, Reg32R


class ADC(Device):
    '''
    Driver for the STM32G4 12-bit ADC.
    '''
    PER_ADC_REGS = [(Reg32,  'ISR',     0x00, [('ADRDY',        1),
                                               ('EOSMP',        1),
                                               ('EOC',          1),
                                               ('EOS',          1),
                                               ('OVR',          1),
                                               ('JEOC',         1),
                                               ('JEOS',         1),
                                               ('AWD1',         1),
                                               ('AWD2',         1),
                                               ('AWD3',         1),
                                               ('JQOVF',        1),
                                               ]),
                    (Reg32,  'IER',     0x04, [('ADRDYIE',      1),
                                               ('EOSMPIE',      1),
                                               ('EOCIE',        1),
                                               ('EOSIE',        1),
                                               ('OVRIE',        1),
                                               ('JEOCIE',       1),
                                               ('JEOSIE',       1),
                                               ('AWD1IE',       1),
                                               ('AWD2IE',       1),
                                               ('AWD3IE',       1),
                                               ('JQOVFIE',      1),
                                               ]),
                    (Reg32,  'CR',      0x08, [('ADEN',         1),
                                               ('ADDIS',        1),
                                               ('ADSTART',      1),
                                               ('JADSTART',     1),
                                               ('ADSTP',        1),
                                               ('JADSTP',       1),
                                               ('',             22),
                                               ('ADVREGEN',     1),
                                               ('DEEPPWD',      1),
                                               ('ADCALDIF',     1),
                                               ('ADCAL',        1),
                                               ]),
                    (Reg32,  'CFGR',    0x0C, [('DMAEN',        1),
                                               ('DMACFG',       1),
                                               ('',             1),
                                               ('RES',          2),
                                               ('EXTSEL0',      1),
                                               ('EXTSEL1',      1),
                                               ('EXTSEL2',      1),
                                               ('EXTSEL3',      1),
                                               ('EXTSEL4',      1),
                                               ('EXTEN',        2),
                                               ('OVRMOD',       1),
                                               ('CONT',         1),
                                               ('AUTDLY',       1),
                                               ('ALIGN',        1),
                                               ('DISCEN',       1),
                                               ('DISCNUM',      3),
                                               ('JDISCEN',      1),
                                               ('JQM',          1),
                                               ('AWD1SGL',      1),
                                               ('AWD1EN',       1),
                                               ('JAWD1EN',      1),
                                               ('JAUTO',        1),
                                               ('AWD1CH',       5),
                                               ('JQDIS',        1),
                                               ]),
                    (Reg32,  'CFGR2',   0x10, [('ROVSE',        1),
                                               ('JOVSE',        1),
                                               ('OVSR',         3),
                                               ('OCSS',         4),
                                               ('TROVS',        1),
                                               ('ROVSM',        1),
                                               ('',             5),
                                               ('GCOMP',        1),
                                               ('',             8),
                                               ('SWTRIG',       1),
                                               ('BULB',         1),
                                               ('SMPTRIG',      1),
                                               ]),
                    (Reg32,  'SMPR1',   0x14, [('SMP0',         3),
                                               ('SMP1',         3),
                                               ('SMP2',         3),
                                               ('SMP3',         3),
                                               ('SMP4',         3),
                                               ('SMP5',         3),
                                               ('SMP6',         3),
                                               ('SMP7',         3),
                                               ('SMP8',         3),
                                               ('SMP9',         3),
                                               ('',             1),
                                               ('SMPPLUS',      1),
                                               ]),
                    (Reg32,  'SMPR2',   0x18, [('SMP10',        3),
                                               ('SMP11',        3),
                                               ('SMP12',        3),
                                               ('SMP13',        3),
                                               ('SMP14',        3),
                                               ('SMP15',        3),
                                               ('SMP16',        3),
                                               ('SMP17',        3),
                                               ('SMP18',        3),
                                               ]),
                    (Reg32,  'TR1',     0x20, [('LT1',          12),
                                               ('AWDFILT',      3),
                                               ('',             1),
                                               ('HT1',          12),
                                               ]),
                    (Reg32,  'TR2',     0x24, [('LT2',          8),
                                               ('',             8),
                                               ('HT2',          8),
                                               ]),
                    (Reg32,  'TR3',     0x28, [('LT3',          8),
                                               ('',             8),
                                               ('HT3',          8),
                                               ]),
                    (Reg32,  'SQR1',    0x30, [('L',            4),
                                               ('',             2),
                                               ('SQ1',          5),
                                               ('',             1),
                                               ('SQ2',          5),
                                               ('',             1),
                                               ('SQ3',          5),
                                               ('',             1),
                                               ('SQ4',          5),
                                               ]),
                    (Reg32,  'SQR2',    0x34, [('SQ5',          5),
                                               ('',             1),
                                               ('SQ6',          5),
                                               ('',             1),
                                               ('SQ7',          5),
                                               ('',             1),
                                               ('SQ8',          5),
                                               ('',             1),
                                               ('SQ9',          5),
                                               ]),
                    (Reg32,  'SQR3',    0x38, [('SQ10',         5),
                                               ('',             1),
                                               ('SQ11',         5),
                                               ('',             1),
                                               ('SQ12',         5),
                                               ('',             1),
                                               ('SQ13',         5),
                                               ('',             1),
                                               ('SQ14',         5),
                                               ]),
                    (Reg32,  'SQR4',    0x3C, [('SQ15',         5),
                                               ('',             1),
                                               ('SQ16',         5),
                                               ]),
                    (Reg32R, 'DR',      0x40, [('RDATA',        16)]),
                    (Reg32,  'JSQR',    0x4C, [('JL',           2),
                                               ('JEXTSEL',      5),
                                               ('JEXTEN',       2),
                                               ('JSQ1',         5),
                                               ('',             1),
                                               ('JSQ2',         5),
                                               ('',             1),
                                               ('JSQ3',         5),
                                               ('',             1),
                                               ('JSQ4',         5),
                                               ]),
                    (Reg32,  'OFR1',    0x60, [('OFFSET1',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET1_CH',   5),
                                               ('OFFSET1_EN',   1),
                                               ]),
                    (Reg32,  'OFR2',    0x64, [('OFFSET2',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET2_CH',   5),
                                               ('OFFSET2_EN',   1),
                                               ]),
                    (Reg32,  'OFR3',    0x68, [('OFFSET3',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET3_CH',   5),
                                               ('OFFSET3_EN',   1),
                                               ]),
                    (Reg32,  'OFR4',    0x6C, [('OFFSET4',      12),
                                               ('',             12),
                                               ('OFFSETPOS',    1),
                                               ('SATEN',        1),
                                               ('OFFSET4_CH',   5),
                                               ('OFFSET4_EN',   1),
                                               ]),
                    (Reg32R, 'JDR1',    0x80, [('JDATA',        16)]),
                    (Reg32R, 'JDR2',    0x84, [('JDATA',        16)]),
                    (Reg32R, 'JDR3',    0x88, [('JDATA',        16)]),
                    (Reg32R, 'JDR4',    0x8C, [('JDATA',        16)]),
                    (Reg32,  'AWD2CR',  0xA0, [('AWD2CH',       19)]),
                    (Reg32,  'AWD3CR',  0xA4, [('AWD3CH',       19)]),
                    (Reg32,  'DIFSEL',  0xB0, [('DIFSEL',       19)]),
                    (Reg32,  'CALFACT', 0xB4, [('CALFACT_S',    7),
                                               ('',             9),
                                               ('CALFACT_D',    7),
                                               ]),
                    (Reg32,  'GCOMP',   0xC0, [('GCOMPCOEFF',   14)]),
                    ]
    COM_ADC_REGS = [Reg32R('CSR', 0x300,      [('ADRDY_MST',    1),
                                               ('EOSMP_MST',    1),
                                               ('EOC_MST',      1),
                                               ('EOS_MST',      1),
                                               ('OVR_MST',      1),
                                               ('JEOC_MST',     1),
                                               ('JEOS_MST',     1),
                                               ('AWD1_MST',     1),
                                               ('AWD2_MST',     1),
                                               ('AWD3_MST',     1),
                                               ('JQOVF_MST',    1),
                                               ('',             5),
                                               ('ADRDY_SLV',    1),
                                               ('EOSMP_SLV',    1),
                                               ('EOC_SLV',      1),
                                               ('EOS_SLV',      1),
                                               ('OVR_SLV',      1),
                                               ('JEOC_SLV',     1),
                                               ('JEOS_SLV',     1),
                                               ('AWD1_SLV',     1),
                                               ('AWD2_SLV',     1),
                                               ('AWD3_SLV',     1),
                                               ('JQOVF_SLV',    1),
                                               ]),
                    Reg32 ('CCR', 0x308,      [('DUAL',         5),
                                               ('',             3),
                                               ('DELAY',        4),
                                               ('',             1),
                                               ('DMACFG',       1),
                                               ('MDMA',         2),
                                               ('CKMODE',       2),
                                               ('PRESC',        4),
                                               ('VREFEN',       1),
                                               ('VSENSESEL',    1),
                                               ('VBATSEL',      1),
                                               ]),
                    Reg32R('CDR', 0x30C,      [('RDATA_MST',    16),
                                               ('RDATA_SLV',    16),
                                               ]),
                    ]

    def __init__(self, target, ap, name, addr, first_adc, nadcs, **kwargs):
        regs = []
        for i in range(nadcs):
            base = 0x100*i
            regs += [cls(_name + ('_%u' % (first_adc + i)), base + offset,
                         fields)
                     for cls, _name, offset, fields in ADC.PER_ADC_REGS]
        regs += ADC.COM_ADC_REGS

        super().__init__(target, ap, addr, name, regs, **kwargs)
